% Copyright 2003 by Roger S. Bivand
%
\name{GRASS.connect}
\alias{GRASS.connect}
\alias{get.LOCATION}
\alias{set.LOCATION}
\alias{get.MAPSET}
\alias{set.MAPSET}
\alias{get.GISDBASE}
\alias{set.GISDBASE}
\alias{get.cygwinstring}
\alias{set.cygwinstring}
\alias{get.GRASSChkGISRC}
\title{Access to underlying environment variables within GRASS}
\description{
Access functions to variables set within GRASS, should normally not be used directly.
}
\usage{
GRASS.connect(manual=FALSE, gisdbase=NULL, loc=NULL, mapset=NULL)
get.GISDBASE()
set.GISDBASE(gisdbase)
get.LOCATION()
set.LOCATION(loc)
get.MAPSET()
set.MAPSET(mapset)
get.cygwinstring()
set.cygwinstring(cygwin)
get.GRASSChkGISRC()
}
\arguments{
 \item{manual}{TRUE to set location parameters manually, FALSE by default}
 \item{gisdbase}{string: full path name to GISDBASE}
 \item{loc}{string: location name}
 \item{mapset}{string: mapset name}
 \item{cygwin}{string: CygWin prefix for prepending to GISRC and GISDBASE
values}
}
\value{
Most of the functions have side effects (apart from those getting values), but otherwise do not return much of use.

In addition, a number of internal GRASS environment variables are exposed for reading and manipulation - these are at present visible but should be used only with caution, and signal the future deprecation of the gmeta() mechanism for handling metadata.
}

%- maybe also `usage' for other objects documented here.
\details{
For users running GRASS under Cygwin with a standard single cygwin root, follow the instructions given as the library is loaded:

> library(GRASS)
If GRASS.connect() fails in this way and you are running under CygWin,
please set the CygWin root file system prefix using: set.cygwinstring()
and re-run GRASS.connect()

In such cases, the cygwin root is for example "c:/cygwin", so the cygwin GISRC variable "/home/rsb/.grassrc5" can be seen by R as "c:/cygwin/home/rsb/.grassrc5", and the GISDBASE field in that file, for example "/usr/local/grass5/data" as 
"c:/cygwin/usr/local/grass5/data".

Where the Cygwin setup is more complex, you will need to set the environment values manually:

Optionally:

> gisrcname <- Sys.getenv("GISRC")
> fix(gisrcname) \# to edit it manually to something readable
> scan(gisrcname, character(0)) \# to have an on-screen version of values

Then:

> GRASS.connect(manual=TRUE, gisdbase="the R readable full path name",
+ loc="LOCATION", mapset="MAPSET")

GRASS.connect() will attempt to insert these values and trap erroneous values.
}
\references{\url{http://grass.itc.it/statsgrass/index.html}, Bivand, R. S., (2000) Using the R statistical data analysis language on GRASS 5.0 GIS data base files. Computers and Geosciences, 26, pp. 1043-1052.}
\author{Roger S. Bivand, e-mail: \email{Roger.Bivand@nhh.no.}}

\keyword{spatial}
\keyword{IO}
\eof
% Copyright 2001 by Roger S. Bivand

\name{contour.G}
\alias{contour.G}
%- Also NEED an `\alias' for EACH other topic documented here.
\title{Equal scale contour plots for GRASS raster and site data}
\description{
contour.G provides a simple interface between grass data objects and the \code{contour()} function}.
\usage{
contour.G(x, layer=NULL, xlab="", ylab="", reverse=NULL, add=FALSE, ...)
}
%- maybe also `usage' for other objects documented here.
\arguments{
 \item{x}{GRASS metadata from \code{gmeta()}}
 \item{layer}{GRASS-ordered raster layer passed on to \code{contour()}}
 \item{xlab}{a title for the x axis, passed to \code{plot()}}
 \item{ylab}{a title for the y axis, passed to \code{plot()}}
 \item{reverse}{see \code{help(reverse)}}
 \item{add}{FALSE for new plot, TRUE to overlay layer on prior plot}
 \item{\dots}{parameters passed through to \code{contour()}}}
\details{
 The function uses \code{asp=1} from the \code{plot.window()} function to
ensure that the scales chosen to be equal on both axes, that is 1cm represents
the same units on each. 
}
\value{
  none
}
\references{\url{http://grass.itc.it/statsgrass/index.html}, Bivand, R. S., (2000) Using the R statistical data analysis language on GRASS 5.0 GIS data base files. Computers and Geosciences, 26, pp. 1043-1052.}
\author{Roger S. Bivand, e-mail: \email{Roger.Bivand@nhh.no.}}

\note{The functions in this package are intended to work with the GRASS geographical information system. The examples for wrapper functions will will work whether or not R is running in GRASS, and whether or not the current location is that of the data set used for the examples. Examples of interface functions will however (from version 0.2-2) only work outside GRASS, to avoid possible overwriting of GRASS database locations and/or files.}

\seealso{\code{\link{plot.window}}, \code{\link{contour}}, \code{\link{plot.grassmeta}}}


\examples{
data(utm.maas)
Zn.o <- as.ordered(cut(utm.maas$Zn, labels=c("insignificant", "low",
"medium", "high", "crisis"), breaks=c(100, 200, 400, 700, 1000, 2000), 
include.lowest=TRUE))
G <- maas.metadata
contour.G(G)
points(utm.maas$east, utm.maas$north, pch=unclass(Zn.o))
legend(x=c(269800, 270500), y=c(5652300, 5653000), pch=c(1:5),
legend=levels(Zn.o))
title("Note equal east and north scales")
contour.G(G, kde2d.G(utm.maas$east, utm.maas$north, h=c(300,300), G=G, Z=utm.maas$Zn)*maasmask)
points(utm.maas$east, utm.maas$north, pch=unclass(Zn.o))
legend(x=c(269800, 270500), y=c(5652300, 5653000), pch=c(1:5),
legend=levels(Zn.o))
title("Kernel density representation of soil Zn")
}
\keyword{spatial}
\keyword{IO}
\eof
% Copyright 2003 by Roger S. Bivand
%
\name{get.mapsets}
\alias{get.mapsets}
\alias{refresh.mapsets}
\title{Access GRASS readable mapsets search path}
\description{
Access GRASS readable mapsets search path by reading the internal structure
read from the \code{SEARCH\_PATH} file in the current mapset root.
}
\usage{
get.mapsets()
refresh.mapsets()
}
\value{
\code{get.mapsets()} returns the current setting as a character vector of 
mapsets, while \code{refresh.mapsets()} returns the updated mapset names, 
also as a character vector.
}
\details{
The functions are needed because the R interface is run as
a GRASS program within which the \code{SEARCH\_PATH} file is
only read once. If, during an R/GRASS session, a command such
as \code{system("g.mapsets mapset=new.mapset")} is given, the
\code{SEARCH\_PATH} file will be updated, but not the values earlier
read into the interface. Consequently, after any \code{system("g.mapsets
mapset=\ldots")}, \code{refresh.mapsets()} should be run to update the
internal values.
}
\references{\url{http://grass.itc.it/statsgrass/index.html}, Bivand,
R. S., (2000) Using the R statistical data analysis language on GRASS
5.0 GIS data base files. Computers and Geosciences, 26, pp. 1043-1052.}
\author{Roger S. Bivand, e-mail: \email{Roger.Bivand@nhh.no.}}

\keyword{spatial}
\keyword{IO}

\eof
% Copyright 1999-2003 by Roger S. Bivand
%
\name{gmeta}
\alias{gmeta}
\alias{east}
\alias{north}
\alias{obsno}
\alias{reverse}
\alias{make.maas.location}
%- Also NEED an `\alias' for EACH other topic documented here.
\title{Reads GRASS metadata from the current LOCATION}
\description{
GRASS LOCATION metadata are read into a list in R, and processed to provide other functions with parameters and structures they require.
}
\usage{
gmeta(interp=FALSE)
east(G)
north(G)
obsno(G)
reverse(G)
make.maas.location()

}
\arguments{
 \item{interp}{if interp is TRUE, the interface uses text transfer through \code{system()}}
 \item{G}{a grassmeta object returned by \code{gmeta}}
}
%- maybe also `usage' for other objects documented here.
\details{
The function retrieves metadata from the GRASS LOCATION from which R was started, and stores it in a list. The metadata is taken from the current, active region, and the implied resolution for raster layers. Next, this is used to create a number of auxilliary objects used by other interface routines. Other auxilliary objects may be constructed using the access functions \code{east}, \code{north}, \code{obsno}, and \code{reverse}. The function returns a list with class \code{grassmeta}:
}
\value{
  \item{LOCATION}{GRASS LOCATION name}
  \item{MAPSET}{GRASS MAPSET within the LOCATION}
  \item{proj}{GRASS projection description}
  \item{n}{Northern edge: numeric}
  \item{s}{Southern edge: numeric}
  \item{w}{Western edge: numeric}
  \item{e}{Eastern edge: numeric}
  \item{nsres}{North-South resolution in measurement units, typically metres or decimal degrees}
  \item{ewres}{East-West resolution in measurement units, typically metres or decimal degrees}
  \item{Nrow}{Number of rows of raster cells}
  \item{Ncol}{Number of columns of raster cells}
  \item{Ncells}{Number of raster cells}
  \item{xlim}{East-West range}
  \item{ylim}{North-South range}
  \item{xseq}{Sequence of raster cell East-West midpoint coordinates}
  \item{yseq}{Sequence of raster cell North-Soutb midpoint coordinates}
  \item{ryseq}{Reversed sequence of raster cell North-Soutb midpoint coordinates}

In addition, a number of internal GRASS environment variables are exposed for reading and manipulation - these are at present visible but should be used only with caution, and signal the future deprecation of the gmeta() mechanism for handling metadata.
}
\references{\url{http://grass.itc.it/statsgrass/index.html}, Bivand, R. S., (2000) Using the R statistical data analysis language on GRASS 5.0 GIS data base files. Computers and Geosciences, 26, pp. 1043-1052.}
\author{Roger S. Bivand, e-mail: \email{Roger.Bivand@nhh.no.}}

\note{The functions in this package are intended to work with the GRASS geographical information system. The examples for wrapper functions will will work whether or not R is running in GRASS, and whether or not the current location is that of the data set used for the examples. Examples of interface functions will however (from version 0.2-2) only work outside GRASS, to avoid possible overwriting of GRASS database locations and/or files.}

\seealso{\code{\link{summary.grassmeta}}}

\examples{
if(!get("maas.loc", env = .GRASS.meta)) make.maas.location()
G <- gmeta()
summary(G)
}
\keyword{spatial}
\keyword{IO}
\eof
% Copyright 1999-2003 by Roger S. Bivand
%
\name{interp.new.G}
\alias{interp.new.G}
%- Also NEED an `\alias' for EACH other topic documented here.
\title{Interpolation from sites to raster, Akima's new method}
\description{
 A wrapper function for \code{interp.new()} in the \code{akima} package.
}
\usage{
interp.new.G(G, x, y, z, extrap=FALSE, duplicate="error", dupfun=NULL,
	reverse=NULL)
}
%- maybe also `usage' for other objects documented here.
\arguments{
 \item{G}{GRASS metadata from gmeta()}
 \item{x}{Eastings of point locations}
 \item{y}{Northings of point locations}
 \item{z}{Observed point values to be interpolated}
 \item{extrap}{see \code{help(interp.new)}}
 \item{duplicate}{see \code{help(interp.new)}}
 \item{dupfun}{see \code{help(interp.new)}}
 \item{reverse}{see \code{help(reverse)}}
}

\value{
  A vector of \code{G$Ncells} values is returned, with the results of interpolation ordered as a GRASS raster file. NAs are inserted outside the convex hull of the data points.
}
\references{\url{http://grass.itc.it/statsgrass/index.html}, Bivand, R. S., (2000) Using the R statistical data analysis language on GRASS 5.0 GIS data base files. Computers and Geosciences, 26, pp. 1043-1052.}
\author{Original \code{interp.new()}: Albrecht Gebhardt as detailed in the akima package documentation; adapted by Roger S. Bivand, \email{Roger.Bivand@nhh.no.}}

\note{The functions in this package are intended to work with the GRASS geographical information system. The examples for wrapper functions will will work whether or not R is running in GRASS, and whether or not the current location is that of the data set used for the examples. Examples of interface functions will however (from version 0.2-2) only work outside GRASS, to avoid possible overwriting of GRASS database locations and/or files.}


\seealso{\code{\link[akima]{interp.new}}}

\examples{
data(utm.maas)
Zn.o <- as.ordered(cut(utm.maas$Zn, labels=c("insignificant", "low",
"medium", "high", "crisis"), breaks=c(100, 200, 400, 700, 1000, 2000), 
include.lowest=TRUE))
G <- maas.metadata
pdata <- cbind(utm.maas$elev, utm.maas$d.river, log(utm.maas$d.river),
    utm.maas$Zn, log(utm.maas$Zn))
colnames(pdata) <- c("Elevation", "Distance", "Ln(Distance)", "Zinc",
    "Ln(Zinc)")
pairs(pdata)
mod1 <- lm(log(Zn) ~ elev + log(d.river), data=utm.maas)
summary(mod1)
anova(mod1)
inregion <- (utm.maas$east >= G$w & utm.maas$east <= G$e) &
  (utm.maas$north >= G$s & utm.maas$north <= G$n)
if(all(!inregion)) stop("None of the site locations are inside the current GRASS region")
if(any(!inregion))
    warning("Some site locations are outside the current GRASS region")
require(akima)
elev.grid <- interp.new.G(G, utm.maas$east, utm.maas$north, utm.maas$elev,
    extrap=TRUE)
brks <- c(-Inf, seq(5.4, 10.6, 0.52), +Inf)
plot(G, elev.grid*maasmask, breaks=brks,
  col=c("yellow", grey(11:2/11), "red"))
plot(G, ifelse(is.na(maasmask), 1, NA), col="wheat", add=TRUE)
title("Bicubic spline interpolation: local elevation")
legend(c(269900, 270600), c(5652000, 5652900), bty="n", bg="wheat",
   legend=c(rev(leglabs(brks)), "mask=NA"),
   fill=c("red", rev(grey(11:2/11)), "yellow", "wheat"))
require(modreg)
ldist <- loess(d.river ~ east * north, data=utm.maas, span=0.2,
 control = loess.control(surface = "direct"))
bank <- predict(ldist, newdata=data.frame(east=east(maas.metadata),
 north=north(maas.metadata)))
b1 <- bank*maasmask
b1[b1 < 5] <- 5
brks <- c(seq(0, 1000, 200), +Inf)
cols <- grey(6:2/6)
plot(maas.metadata, b1, breaks=brks, col=c(cols, "red"))
plot(maas.metadata, ifelse(is.na(maasmask), 1, NA), col="wheat", add=TRUE)
title("Loess predictions of distance from river bank")
legend(c(269900, 270600), c(5652000, 5652900), bty="n", bg="wheat",
   legend=c(rev(leglabs(brks)), "mask=NA"),
 fill=c("red", rev(cols), "wheat"))
new <- data.frame(elev=elev.grid*maasmask, d.river=b1)
pr.mod1 <- predict(mod1, new, se.fit=TRUE)
rm(new, elev.grid, bank)
v.pr <- rep(NA, G$Ncells)
v.pr[as.integer(names(pr.mod1$fit))] <- pr.mod1$fit
summary(v.pr)
summary(exp(v.pr))
plot(G, exp(v.pr), breaks=c(-200, round(seq(142, 1154, length=9)), 5000),
  col=c("yellow", grey(9:2/9), "red"))
plot(G, ifelse(is.na(maasmask), 1, NA), col="wheat", add=TRUE)
title("Regression predictions of Zn levels, (B&McD p. 113)")
legend(c(269900, 270600), c(5652000, 5652900), bty="n", bg="wheat",
   legend=c("> 1154", rev(legtext(round(seq(142, 1154, length=9)))), "< 142",
   "mask=NA"), fill=c("red", rev(grey(9:2/9)), "yellow", "wheat"))
v.pr[as.integer(names(pr.mod1$se.fit))] <- pr.mod1$se.fit
plot(G, exp(v.pr), col=grey(16:2/16))
plot(G, ifelse(is.na(maasmask), 1, NA), col="wheat", add=TRUE)
points(utm.maas$east, utm.maas$north, pch=18)
title("Standard error of predictions")
Zn.grid <- interp.new.G(G, utm.maas$east, utm.maas$north, utm.maas$Zn,
    extrap=TRUE)
plot(G, Zn.grid*maasmask, breaks=c(-500, round(seq(15,1994,length=9)), 3000),
  col=c("yellow", grey(9:2/9), "red"))
plot(G, ifelse(is.na(maasmask), 1, NA), col="wheat", add=TRUE)
title(xlab="B&McD p. 118", main="Bicubic spline interpolation: Zn ppm")
legend(c(269900, 270600), c(5652000, 5652900), bty="n", bg="wheat",
   legend=c("> 1994", rev(legtext(round(seq(15,1994,length=9)))), "< 15",
   "mask=NA"), fill=c("red", rev(grey(9:2/9)), "yellow", "wheat"))
\dontrun{
sites.put2(G, utm.maas, dims=c("east", "north", "elev"),
  lname="ex.utm.maas1", check=FALSE)
system("s.surf.idw input=ex.utm.maas1 output=Zn.idw npoints=98 field=7")
idw <- rast.get(G, "Zn.idw")
plot(G, idw$Zn.idw*maasmask, breaks=c(-100, round(seq(15,1994,length=9)), 3000),
  col=c("yellow", grey(9:2/9), "red"))
plot(G, ifelse(is.na(maasmask), 1, NA), col="wheat", add=TRUE)
title(xlab="B&McD p. 118",
  main="Inverse squared distance interpolation: Zn ppm")
legend(c(269900, 270600), c(5652000, 5652900), bty="n", bg="wheat",
  legend=c("> 1994", rev(legtext(round(seq(15,1994,length=9)))), "< 15",
  "mask=NA"), fill=c("red", rev(grey(9:2/9)), "yellow", "wheat"))
}
}
\keyword{spatial}
\keyword{IO}
\eof
% Copyright 1999-2000 by Roger S. Bivand
%
\name{kde2d.G}
\alias{kde2d.G}
%- Also NEED an `\alias' for EACH other topic documented here.
\title{Two-Dimensional Kernel Density Estimation on a GRASS Grid}
\description{
 A version of \code{kde2d()} in the MASS package of the VR collection using the metadata of the underlying GRASS LOCATION. \code{kde2d()} is for "two-dimensional kernel density estimation with an axis-aligned bivariate normal kernel, evaluated on a square grid." An optional feature is the introduction of a weighted moving average through the Z argument.
}
\usage{
kde2d.G(G, x, y, h, reverse=NULL, Z=NULL)
}
%- maybe also `usage' for other objects documented here.
\arguments{
 \item{G}{GRASS metadata from \code{gmeta()}}
 \item{x}{x coordinate of data}
 \item{y}{y coordinate of data}
 \item{h}{vector of bandwidths for x and y directions.
             Defaults to normal reference bandwidth.}
 \item{reverse}{see \code{help(reverse)}}
 \item{Z}{vector of attribute values}
}
\value{
  A vector of \code{G$Ncells} values is returned, with the results of density/weighted moving average calculations ordered as a GRASS raster file. Density values are points per unit area, while moving average values are in the units of the Z variable.
}
\references{\url{http://grass.itc.it/statsgrass/index.html}, Bivand, R. S., (2000) Using the R statistical data analysis language on GRASS 5.0 GIS data base files. Computers and Geosciences, 26, pp. 1043-1052.}
\author{Original \code{kde2d(), bandwidth.nrd()}: Brian D. Ripley and Bill Venables as detailed in the MASS package documentation; adapted by Roger S. Bivand, e-mail: \email{Roger.Bivand@nhh.no.}}

\note{The functions in this package are intended to work with the GRASS geographical information system. The examples for wrapper functions will will work whether or not R is running in GRASS, and whether or not the current location is that of the data set used for the examples. Examples of interface functions will however (from version 0.2-2) only work outside GRASS, to avoid possible overwriting of GRASS database locations and/or files.}


\seealso{\code{\link[MASS]{kde2d}}}

\examples{
data(utm.maas)
G <- maas.metadata
inregion <- (utm.maas$east >= G$w & utm.maas$east <= G$e) &
  (utm.maas$north >= G$s & utm.maas$north <= G$n)
if(all(!inregion)) stop("None of the site locations are inside the current GRASS region")
if(any(!inregion)) warning("Some site locations are outside the current GRASS region")
plot(G, kde2d.G(G=G, utm.maas$east, utm.maas$north, h=c(300,300))*maasmask)
points(utm.maas$east, utm.maas$north)
rug(utm.maas$east, side=1, ticksize=0.02)
rug(utm.maas$north, side=2, ticksize=0.02)
title(main="Kernel estimates of density of soil sample placing",
  xlab="(Bailey & Gatrell, pp. 84-88")
plot(G, kde2d.G(G=G, utm.maas$east, utm.maas$north, h=c(300,300), Z=utm.maas$Zn)*maasmask)
points(utm.maas$east, utm.maas$north)
rug(utm.maas$east, side=1, ticksize=0.02)
rug(utm.maas$north, side=2, ticksize=0.02)
title(main="Kernel density weighted average, Zn ppm",
  xlab="(Bailey & Gatrell, pp. 159-161")
}
\keyword{spatial}
\keyword{IO}
\eof
\name{krige.G}
\alias{krige.G}
\alias{prmat2.G}
\alias{semat2.G}
%- Also NEED an `\alias' for EACH other topic documented here.
\title{Kriging prediction for GRASS maps}
\description{
  The function is a modified and simplified version of the sgeostat \code{krige()} function, using the current GRASS region to generate points for ordinary kriging prediction. Based in part on advice from Albrecht Gebhardt (for the implementation of which I am responsible!), it uses compiled code from the spatial library, and only supports exponential, gaussian, and spherical variogram models. The examples also illustrate the use of the contributed \code{fields} package.
}
\usage{
krige.G(point.obj, at, var.mod.obj, G, mask=NULL)
}
%- maybe also `usage' for other objects documented here.
\arguments{
  \item{point.obj}{The point data frame used for fitting the variogram}
  \item{at}{The string name of the variable in \code{point.obj} to be predicted}
  \item{var.mod.obj}{The chosen fitted variogram model}
  \item{G}{A grassmeta object describing the current GRASS region}
  \item{mask}{A vector of length \code{east(G)} with NA's in locations for which no prediction is needed}
}
\details{
  The function appears to correspond to Gstat
  (\url{http://www.geog.uu.nl/gstat}) ordinary kriging predictions for
  point locations. The specific links between the sgeostat variogram
  models and the spatial \code{surf.gls} covariance arguments are:
  \code{se=sqrt(nugget+sill)}, \code{alpha=nugget/(nugget+sill)},
  and \code{d=range}.

}
\value{
  The function returns a list of three components:
  \item{kr}{trgls object returned by surf.gls}
  \item{zhat}{kriging predictions}
  \item{sehat}{kriging standard errors}
  ...
}
\references{\url{http://grass.itc.it/statsgrass/index.html}, \url{http://www.gis.iastate.edu/SGeoStat/homepage.html}; Bivand, R. S., (2000) Using the R statistical data analysis language on GRASS 5.0 GIS data base files. Computers and Geosciences, 26, pp. 1043-1052.}
\author{Original \code{krige()}: as detailed in the sgeostat package documentation and Albrecht Gephardt, the package's R maintainer; adapted by Roger S. Bivand, e-mail: \email{Roger.Bivand@nhh.no.}}

\note{The functions in this package are intended to work with the GRASS geographical information system. The examples for wrapper functions will will work whether or not R is running in GRASS, and whether or not the current location is that of the data set used for the examples. Examples of interface functions will however (from version 0.2-2) only work outside GRASS, to avoid possible overwriting of GRASS database locations and/or files.}


\seealso{\code{\link[spatial]{surf.gls}}, \code{\link[spatial]{prmat}},
 \code{\link[spatial]{semat}}, \code{\link[sgeostat]{est.variogram}},
 \code{\link[sgeostat]{fit.exponential}}}


\examples{
data(utm.maas)
G <- maas.metadata
inregion <- (utm.maas$east >= G$w & utm.maas$east <= G$e) &
 (utm.maas$north >= G$s & utm.maas$north <= G$n)
if(all(!inregion))
 stop("None of the site locations are inside the current GRASS region")
if(any(!inregion))
 warning("Some site locations are outside the current GRASS region")
require(sgeostat)
maas.pts <- point(utm.maas, x="east", y="north")
maas.pairs <- pair(maas.pts, num.lags=10, maxdist=1000)
maas.evg <- est.variogram(maas.pts, maas.pairs, a1="Zn")
plot(maas.evg)
text(maas.evg$bins, maas.evg$classic/2, labels=maas.evg$n, pos=1)
abline(h=25000)
abline(h=170000)
maas.fit.exp <- fit.exponential(maas.evg, c0=24803.4, ce=158232,
 ae=361.604, plot.it=TRUE, iterations=0)
cat("Using parameters from B&McD, p. 142 without fitting.\n")
res.G1 <- krige.G(maas.pts, "Zn", maas.fit.exp, G, maasmask)
summary(res.G1$zhat)
summary(res.G1$sehat)
plot(G, res.G1$zhat, breaks=round(seq(120,1660,length=9)), col=grey(9:2/9))
plot(G, ifelse(is.na(maasmask), 1, NA), col="wheat", add=TRUE)
legend(c(269900, 270600), c(5652000, 5652900), bty="n", bg="wheat",
 legend=c(rev(legtext(round(seq(120,1660,length=9)))), "mask=NA"),
 fill=c(rev(grey(9:2/9)), "wheat"))
title("Ordinary kriging predictions")
}
\keyword{spatial}
\keyword{IO}
\eof
% Copyright 2003 by Roger S. Bivand
%
\name{list.grass}
\alias{list.grass}
\alias{print.glist}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{List GRASS database elements}
\description{
  A helper function to list GRASS database elements, using compiled access to GRASS - for an interpreted alternative use system("g.list").
}
\usage{
list.grass(type = "cell")
print.glist(x, ...)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{type}{one of "cell", "site\_lists", or "dig\_plus"}
  \item{x}{a glist object returned by list.grass()}
  \item{...}{arguments passed to print methods}
}
\value{
  A glist object, a named list of database elements in character vectors, one character vector for each MAPSET in the mapsets returned by get.mapsets()
}
\references{\url{http://grass.itc.it/statsgrass/index.html}}
\author{Roger S. Bivand, e-mail: \email{Roger.Bivand@nhh.no.}}
\keyword{spatial}
\eof
% Copyright 1999-2000 by Roger S. Bivand
%
\name{pcbs}
\alias{pcbs}
\docType{data}
\title{PCBs in an area of South Wales}
\usage{data(pcbs)}
\description{
The \code{pcbs} data frame has 70 rows and 3 columns.
It records contamination of the environment with polychlorinated biphenyls around the site of a large plant for the incineration of chemical wastes near Pontypool, South Wales.
}
\format{
  This data frame contains the following columns:
  \describe{
    \item{east}{a numeric vector - UTM zone 30 eastings coordinates}
    \item{north}{a numeric vector - UTM zone 30 northings coordinates}
    \item{pcbs}{a numeric vector - standardised scores for seven types of PCB}
  }
}
\details{
 The original data were positioned in relation to National Grid coordinates, and have been reprojected to UTM zone 30, using the WGS84 ellipsoid.
}
\source{
 Bailey, T. C., Gatrell, A. C. 1995 Interactive Spatial Data Analysis (Longman, Harlow); pages 149-150, courtesy of Andrew Lovett, School of Environmental Sciences, University of East Anglia.
}
\note{This dataset will only work if R is started from inside GRASS, choosing the location for the Pontypool PCBs data. GRASS installations differ in permissions needed to establish a new location, and system administrator privileges may be needed to create the Pontypool location. Information about the necessary metadataare as follows. The actual data may be accessed from R: \code{data(pcbs)}.
  \describe{
    \item{projection }{UTM}
    \item{ellipsoid }{WGS84}
    \item{zone }{30}
    \item{north }{77200}
    \item{south }{74500}
    \item{west }{68000}
    \item{east }{70200}
    \item{nsres }{25}
    \item{ewres }{25}
    \item{rows }{108}
    \item{cols }{88}
  }
}

\examples{
data(pcbs)
pcbs.o <- as.ordered(cut(pcbs$pcbs, labels=c("insignificant", "low",
"medium", "high", "crisis"), breaks=c(1,20,100,500,1000,5000),
include.lowest=TRUE))
table(pcbs.o)
plot(pcbs$east, pcbs$north, pch=unclass(pcbs.o), xlab="", ylab="", asp=1)
legend(x=c(67980, 68480), y=c(74710, 75180), pch=c(1:5), legend=levels(pcbs.o))

}
\keyword{datasets}
\eof
% Copyright 1999-2000 by Roger S. Bivand
%
\name{plot.grassmeta}
\alias{plot.grassmeta}
\alias{legtext}
\alias{leglabs}
\alias{findInterval2}
%- Also NEED an `\alias' for EACH other topic documented here.
\title{Equal scale plots for GRASS raster and site data}
\description{
plot.grassmeta provides a simple interface between grass data objects and the \code{image()} function; category layers may be plotted by taking \code{unclass()} of the layer, and setting zlim to non-default values. If layer is not set, a blank base map is plotted, for instance for use with \code{points()}.
}
\usage{
plot.grassmeta(x, layer=NULL, xlab="", ylab="", reverse=NULL, add=FALSE,
 breaks=NULL, ...)
legtext(break.levels)
leglabs(x1, under="under", over="over", between="-")
findInterval2(x2, vec, rightmost.closed = FALSE, all.inside = TRUE)}

%- maybe also `usage' for other objects documented here.
\arguments{
 \item{x}{GRASS metadata from \code{gmeta()}}
 \item{layer}{GRASS-ordered raster layer passed on to \code{image()}}
 \item{xlab}{a title for the x axis, passed to \code{plot()}}
 \item{ylab}{a title for the y axis, passed to \code{plot()}}
 \item{reverse}{see \code{help(reverse)}}
 \item{add}{FALSE for new plot, TRUE to overlay layer on prior plot}
 \item{\dots}{parameters passed through to \code{image()}}
 \item{break.levels}{vector of image break levels}
 \item{breaks}{vector of image break levels}
 \item{x1}{in leglabs(), a vector of breaks}
 \item{under}{character value to denote under}
 \item{over}{character value to denote over}
 \item{between}{character value to denote between}
 \item{x2}{see findInterval()}
 \item{vec}{in findInterval2(), a vector of breaks}
 \item{rightmost.closed}{see findInterval()}
 \item{all.inside}{see findInterval()}
}
\details{
 The function uses \code{asp=1} from the \code{plot.window()} function to
ensure that the scales chosen to be equal on both axes, that is 1cm represents
the same units on each. The \code{legtext} function is a small helper to aid
in converting image break levels into legend texts, taking a numeric argument
as \code{image(break=)}, and returning a character vector.
}
\value{
  none
}
\references{\url{http://grass.itc.it/statsgrass/index.html}, Bivand, R. S., (2000) Using the R statistical data analysis language on GRASS 5.0 GIS data base files. Computers and Geosciences, 26, pp. 1043-1052.}
\author{Roger S. Bivand, e-mail: \email{Roger.Bivand@nhh.no.}}

\note{The functions in this package are intended to work with the GRASS geographical information system. The examples for wrapper functions will will work whether or not R is running in GRASS, and whether or not the current location is that of the data set used for the examples. Examples of interface functions will however (from version 0.2-2) only work outside GRASS, to avoid possible overwriting of GRASS database locations and/or files.}

\seealso{\code{\link{plot.window}}, \code{\link{image}}}

\examples{
data(utm.maas)
Zn.o <- as.ordered(cut(utm.maas$Zn, labels=c("insignificant", "low",
"medium", "high", "crisis"), breaks=c(100, 200, 400, 700, 1000, 2000), 
include.lowest=TRUE))
G <- maas.metadata
plot(G)
points(utm.maas$east, utm.maas$north, pch=unclass(Zn.o))
legend(x=c(269800, 270500), y=c(5652300, 5653000), pch=c(1:5),
legend=levels(Zn.o))
title("Note equal east and north scales")
example(kde2d.G)
}
\keyword{spatial}
\keyword{IO}
\keyword{hplot}
\eof
% Copyright 1999-2000 by Roger S. Bivand
%
\name{rast.get}
\alias{rast.get}
%- Also NEED an `\alias' for EACH other topic documented here.
\title{Import GRASS raster files}
\description{
\code{rast.get()} moves one or more GRASS 5.0 raster files to a list, returning the filled object. Setting \code{catlabels} elements, corresponding to the files named in rlist, to TRUE, imports category labels instead of codes yielding an ordered factor rather than a numeric vector, and requires more memory.
}
\usage{
rast.get(G, rlist="", catlabels=NULL, debug=FALSE, interp=FALSE)
}
\details{
\code{rast.get()} assumes firstly that the region of the GRASS LOCATION has not been changed since gmeta() was last run, secondly that resolutions of the requested map layers and the GRASS LOCATION are in accord, and thirdly that the data cover the selected region. If the second or third assumptions are not met for the interpreted version, the GRASS program \code{r.stats} run through \code{system()} will read from the underlying map layers according to the new region setting, yielding cell values at the current resolution, and inserting NAs in areas for which there are no data. For the compiled version, the user is required to work within a given map region at the same resolution.
}
%- maybe also `usage' for other objects documented here.
\arguments{
 \item{G}{GRASS metadata from \code{gmeta()}}
 \item{rlist}{character vector of GRASS raster file names}
 \item{catlabels}{logical vector of length \code{length(rlist)}: if TRUE, GRASS category raster layers are imported as ordered factors, if FALSE, as numeric only}
 \item{debug}{if TRUE, the temporary ASCII file used for transfer is not deleted on exit from the function}
 \item{interp}{if TRUE, the interpreted version of the function is used instead of the loaded compiled version}
}
\value{
  A list is returned with \code{length(rlist)} vectors and \code{G$Ncells} values in each vector; the columns are named using the names of the imported GRASS raster files. Those imported with category labels are ordered factors, and their names are suffixed with \code{.f}
}
\references{\url{http://grass.itc.it/statsgrass/index.html}, Bivand, R. S., (2000) Using the R statistical data analysis language on GRASS 5.0 GIS data base files. Computers and Geosciences, 26, pp. 1043-1052.}
\author{Roger S. Bivand, e-mail: \email{Roger.Bivand@nhh.no.}}

\note{The functions in this package are intended to work with the GRASS geographical information system. The examples for wrapper functions will will work whether or not R is running in GRASS, and whether or not the current location is that of the data set used for the examples. Examples of interface functions will however (from version 0.2-2) only work outside GRASS, to avoid possible overwriting of GRASS database locations and/or files.}

\seealso{\code{\link{rast.put}}}

\examples{
if(!get("maas.loc", env = .GRASS.meta)) make.maas.location()
data(utm.maas)
Zn.o <- as.ordered(cut(utm.maas$Zn, labels=c("insignificant", "low",
"medium", "high", "crisis"), breaks=c(100, 200, 400, 700, 1000, 2000), 
include.lowest=TRUE))
G <- gmeta()
if(length(ls(pat="nameR"))==0){example(rast.put)}
exget <- rast.get(G, rlist=c("ex.Zn.grid.in", "ex.tr3.in",
  "ex.Zn.grid.o.in"), catlabels=as.logical(c(FALSE, FALSE, TRUE)))
oldpar <- par(mfrow=c(1,2))
plot(G, exget$ex.Zn.grid.in)
points(utm.maas$east, utm.maas$north, pch=18)
title("Bicubic spline interpolation")
plot(G, exget$ex.tr3.in)
points(utm.maas$east, utm.maas$north, pch=18)
title("Cubic trend surface")
par(oldpar)
table(exget$ex.Zn.grid.o.in)
}
\keyword{spatial}
\keyword{IO}
\eof
% Copyright 1999-2000 by Roger S. Bivand
%
\name{rast.put}
\alias{rast.put}
%- Also NEED an `\alias' for EACH other topic documented here.
\title{Exports to GRASS raster data files}
\description{
 \code{rast.put()} moves a single numeric vector to GRASS, using the metadata from \code{gmeta()}. If the compiled function is loaded, ordered factors are assigned category labels from the factor levels.
}
\usage{
rast.put(G, lname="", layer, title="", cat=FALSE, DCELL=FALSE, breaks=NULL,
 col=NULL, nullcol=NULL, defcol=NULL, debug=FALSE, interp=FALSE, check=TRUE)
}
%- maybe also `usage' for other objects documented here.
\arguments{
 \item{G}{GRASS metadata from \code{gmeta()}}
 \item{lname}{Name for new GRASS raster data file}
 \item{layer}{numeric vector or factor for export with length of \code{G$Ncells} in GRASS order}
 \item{title}{character string to describe new GRASS raster data file}
 \item{cat}{if TRUE, the layer is read into GRASS as integer, for codes of category factors}
 \item{DCELL}{if TRUE, the layer is read into GRASS in double precision, otherwise (default) in single precision, unless the GRASS environment variable \code{GRASS_FP_DOUBLE} is set, overriding DCELL}
 \item{breaks}{a set of breakpoints for quantization if required: must give one more breakpoint than colour; only for cat=FALSE and interp=FALSE.}
 \item{col}{a list of colors such as that generated by `rainbow', `heat.colors', `topo.colors', `terrain.colors' or similar functions; the default is a grey ramp; only for interp=FALSE, for cat=TRUE must equal number of factor levels.}
 \item{nullcol}{Colour to be used for NA values - "honeydew"}
 \item{defcol}{Default colour to be used where no other is defined - "pale turquoise"}
 \item{debug}{if TRUE, the temporary ASCII file used for transfer in interpreted mode is not deleted on exit from the function}
 \item{interp}{if TRUE, the interpreted version of the function is used instead of the loaded compiled version}
 \item{check}{if TRUE, existing raster layers will not be overwritten}
}
\details{If cat=TRUE, then the R factor layer is moved to the current GRASS location and mapset as a CELL layer, with labels taken from the factor levels; for this case breaks is disregarded (they are implicit in the factor), and col must be either NULL or a vector of colours equal in length to the number of levels. When col=NULL, grey() is used to generate the colours. If cat=FALSE, the R numeric layer is moved to GRASS as an FCELL or DCELL layer (depending on DCELL or the GRASS environmental variable \code{GRASS_FP_DOUBLE}. In this case breaks are used for quantization and colour assignment in connection with col. If breaks=NULL, pretty() is used to yield about 20 "nice" values for quantization, and their values are used to generate labels.}
\references{\url{http://grass.itc.it/statsgrass/index.html}, Bivand, R. S., (2000) Using the R statistical data analysis language on GRASS 5.0 GIS data base files. Computers and Geosciencesi, 26, pp. 1043-1052.}
\author{Roger S. Bivand, e-mail: \email{Roger.Bivand@nhh.no.}}

\note{The functions in this package are intended to work with the GRASS geographical information system. The examples for wrapper functions will will work whether or not R is running in GRASS, and whether or not the current location is that of the data set used for the examples. Examples of interface functions will however (from version 0.2-2) only work outside GRASS, to avoid possible overwriting of GRASS database locations and/or files.}

\seealso{\code{\link{rast.get}}}

\examples{
if(!get("maas.loc", env = .GRASS.meta)) make.maas.location()
data(utm.maas)
G <- gmeta()
inregion <- (utm.maas$east >= G$w & utm.maas$east <= G$e) & (utm.maas$north >= G$s & utm.maas$north <= G$n)
if(all(!inregion)) stop("None of the site locations are inside the current GRASS region")
if(any(!inregion)) warning("Some site locations are outside the current GRASS region")
require(akima)
Zn.grid <- interp.new.G(G, utm.maas$east, utm.maas$north, utm.maas$Zn,
    extrap=TRUE)*maasmask
require(spatial)
s3 <- trmat.G(G, surf.ls(3, utm.maas$east, utm.maas$north,
    utm.maas$Zn))*maasmask
Zn.grid.o <- as.ordered(cut(Zn.grid, labels=c("insignificant", "low",
"medium", "high", "crisis"), breaks=c(-300, 200, 400, 700, 1000, 5000), include.lowest=TRUE))
nameR <- c("ex.Zn.grid.in", "ex.tr3.in", "ex.Zn.grid.o.in")
rast.put(G, lname=nameR[1], layer=Zn.grid, title="Akima spline interpolation",
 check=FALSE)
rast.put(G, lname=nameR[2], layer=s3, title="Cubic trend surface",
 check=FALSE)
rast.put(G, lname=nameR[3], layer=Zn.grid.o, cat=TRUE, 
  title="Interpolated surface categories", check=FALSE)
}
\keyword{spatial}
\keyword{IO}
\eof
% Copyright 1999-2003 by Roger S. Bivand
%
\name{sites.get}
\alias{sites.get}
%- Also NEED an `\alias' for EACH other topic documented here.
\title{Import GRASS sites file}
\description{
 \code{sites.get} moves one GRASS 5.0 sites file to a data frame, returning the filled object.
}
\usage{
sites.get(G, slist="", all.sites=FALSE, collapse.labels=TRUE, debug=FALSE, interp=FALSE)
}
%- maybe also `usage' for other objects documented here.
\arguments{
 \item{G}{GRASS metadata from \code{gmeta()}}
 \item{slist}{GRASS sites file name}
 \item{all.sites}{if FALSE, retreive only sites in current GRASS region, if TRUE, retreive all sites}
 \item{collapse.labels}{If the sites file is old-style or malformed (d.sites.pg map=), collapse label strings to single string per point}
 \item{debug}{if TRUE, the temporary ASCII file used for transfer in interpreted mode is not deleted on exit from the function}
 \item{interp}{if TRUE, the interpreted version of the function is used instead of the loaded compiled version}
}
\value{
  A data frame with columns: east, north, and var1, ..., varn, where n is the number of attributes held in the GRASS sites file, some of which may be factors, and which may include the site id number. Under the interpreted interface, the attributes are named var1, var2, etc., under the compiled interface as id, str1, str2, etc., num1, num2, etc., unless the sites file has a labels header containing the same number of labels as the number of columns in the data table returned, in which case the labels are used.
}
\references{\url{http://grass.itc.it/statsgrass/index.html}, Bivand, R. S., (2000) Using the R statistical data analysis language on GRASS 5.0 GIS data base files. Computers and Geosciences, 26, pp. 1043-1052.}
\author{Roger S. Bivand, e-mail: \email{Roger.Bivand@nhh.no.}}

\note{The functions in this package are intended to work with the GRASS geographical information system. The examples for wrapper functions will will work whether or not R is running in GRASS, and whether or not the current location is that of the data set used for the examples. Examples of interface functions will however (from version 0.2-2) only work outside GRASS, to avoid possible overwriting of GRASS database locations and/or files.}

\seealso{\code{\link{sites.put}}}

\examples{
if(!get("maas.loc", env = .GRASS.meta)) make.maas.location()
G <- gmeta()
example(sites.put)
ex.Zn.log <- sites.get(G, slist="ex.Znlog.in")
mean(ex.Zn.log$log.Zn - log(utm.maas$Zn))
ex.Zn.cat <- sites.get(G, slist="ex.Zncat.in")
table(Zn.o, ex.Zn.cat$Zn.o)
utm.maas.new <- sites.get(G, slist="ex.utm.maas")
names(utm.maas.new)
table(Zn.o, utm.maas.new$Zn.o)
}
\keyword{spatial}
\keyword{IO}
\eof
% Copyright 1999-2003 by Roger S. Bivand
%
\name{sites.put}
\alias{sites.put}
\alias{sites.put2}
%- Also NEED an `\alias' for EACH other topic documented here.
\title{Export GRASS sites file}
\description{
 \code{sites.put()} moves a single numeric or character vector site to GRASS, using the metadata from \code{gmeta(). \code{sites.put2()}} moves a data frame to a GRASS sites list, and requires the specification of the columns of the data frame to be treated as dimensions.
}
\usage{
sites.put(G, lname="", east, north, var, debug=FALSE)
sites.put2(G, data, id=NULL, dims, lname="", all.sites=FALSE,
	check=TRUE)
}
%- maybe also `usage' for other objects documented here.
\arguments{
 \item{G}{GRASS metadata from \code{gmeta()}}
 \item{lname}{Name for new GRASS sites file}
 \item{east}{Eastings of points}
 \item{north}{Northings of points}
 \item{var}{numeric or character vector of attribute values at these points for export}
 \item{debug}{if TRUE, the temporary ASCII file used for transfer is not deleted on exit from the function}
 \item{data}{data frame to be exported as a GRASS 5.0 format sites list}
 \item{id}{default NULL, can be the index or name of a numeric column in data}
 \item{dims}{character vector of column names or integer vector of column indices in data for sites list coordinates, expected to be in x, y, z1, ... order}
 \item{all.sites}{if FALSE, retreive only sites in current GRASS region, if TRUE, retreive all sites}
 \item{check}{check to see if \code{lname} already exists as a sites list in the GRASS database, and abort if it does; if FALSE \code{sites.put2()} will overwrite existing files (default TRUE)}
}
\value{
  none
}
\references{\url{http://grass.itc.it/statsgrass/index.html}, Bivand, R. S., (2000) Using the R statistical data analysis language on GRASS 5.0 GIS data base files. Computers and Geosciences, 26, pp. 1043-1052.}
\author{Roger S. Bivand, e-mail: \email{Roger.Bivand@nhh.no.}}

\note{The functions in this package are intended to work with the GRASS geographical information system. The examples for wrapper functions will will work whether or not R is running in GRASS, and whether or not the current location is that of the data set used for the examples. Examples of interface functions will however (from version 0.2-2) only work outside GRASS, to avoid possible overwriting of GRASS database locations and/or files.}

\seealso{\code{\link{sites.get}}}

\examples{
if(!get("maas.loc", env = .GRASS.meta)) make.maas.location()
data(utm.maas)
Zn.o <- as.ordered(cut(utm.maas$Zn, labels=c("insignificant", "low",
"medium", "high", "crisis"), breaks=c(100, 200, 400, 700, 1000, 2000), 
include.lowest=TRUE))
G <- gmeta()
nameQ <- c("ex.Zn.in", "ex.Znlog.in", "ex.Zncat.in")
Zn <- data.frame(east=utm.maas$east, north=utm.maas$north, Zn=utm.maas$Zn)
sites.put2(G, Zn, dims=c("east", "north"), lname=nameQ[1], check=FALSE)
log.Zn <- data.frame(east=utm.maas$east, north=utm.maas$north,
 log.Zn=log(utm.maas$Zn))
sites.put2(G, log.Zn, dims=c("east", "north"), lname=nameQ[2], check=FALSE)
Zn.o.df <- data.frame(east=utm.maas$east, north=utm.maas$north, Zn.o=Zn.o)
sites.put2(G, Zn.o.df, dims=c("east", "north"), lname=nameQ[3], check=FALSE)
newdf <- data.frame(utm.maas, Zn.o)
sites.put2(G, newdf, dims=c("east", "north", "elev"), lname="ex.utm.maas",
 check=FALSE)
}
\keyword{spatial}
\keyword{IO}
\eof
% Copyright 1999-2000 by Roger S. Bivand
%
\name{summary.grassmeta}
\alias{summary.grassmeta}
%- Also NEED an `\alias' for EACH other topic documented here.
\title{Display GRASS metadata}
\description{
 \code{summary.grassmeta()} displays the metadata collected by gmeta().
}
\usage{
summary.grassmeta(object, ...)
}
%- maybe also `usage' for other objects documented here.
\arguments{
 \item{object}{GRASS metadata from \code{gmeta()}}
 \item{...}{other generic arguments}
}
\references{\url{http://grass.itc.it/statsgrass/index.html}, Bivand, R. S., (2000) Using the R statistical data analysis language on GRASS 5.0 GIS data base files. Computers and Geosciences, 26, pp. 1043-1052.}
\author{Roger S. Bivand, e-mail: \email{Roger.Bivand@nhh.no.}}

\note{The functions in this package are intended to work with the GRASS geographical information system. The examples for wrapper functions will will work whether or not R is running in GRASS, and whether or not the current location is that of the data set used for the examples. Examples of interface functions will however (from version 0.2-2) only work outside GRASS, to avoid possible overwriting of GRASS database locations and/or files.}

\seealso{\code{\link{gmeta}}}

\examples{
if(!get("maas.loc", env = .GRASS.meta)) make.maas.location()
G <- gmeta()
summary(G)
}
\keyword{spatial}
\keyword{IO}
\eof
% Copyright 1999-2000 by Roger S. Bivand
%
\name{trmat.G}
\alias{trmat.G}
\title{Evaluate Trend Surface over a GRASS Grid}
\description{
 A wrapper for \code{trmat()} from the \code{spatial} package in the VR bundle, using the metadata of the underlying GRASS LOCATION.
}
\usage{
trmat.G(G, obj, east=NULL, north=NULL)
}
%- maybe also `usage' for other objects documented here.
\arguments{
 \item{G}{GRASS metadata from \code{gmeta()}}
 \item{obj}{object returned by \code{surf.ls} or \code{surf.gls}}
 \item{east}{see \code{help(east)}}
 \item{north}{see \code{help(north)}}
}

\value{
  A vector of \code{G$Ncells} values is returned, with the results of interpolation ordered as a GRASS raster file.
}
\references{\url{http://grass.itc.it/statsgrass/index.html}, Bivand, R. S., (2000) Using the R statistical data analysis language on GRASS 5.0 GIS data base files. \emph{Computers and Geosciences}, 26, pp. 1043-1052; Unwin, D. J., Wrigley, N. (1987) Towards a general-theory of control point distribution effects in trend surface models. \emph{Computers and Geosciences}, 13, pp. 351-355.}
\author{Original \code{trmat()}: Brian D. Ripley and Bill Venables as detailed in the spatial package documentation; adapted by Roger S. Bivand, e-mail: \email{Roger.Bivand@nhh.no.}}

\note{The functions in this package are intended to work with the GRASS geographical information system. The examples for wrapper functions will will work whether or not R is running in GRASS, and whether or not the current location is that of the data set used for the examples. Examples of interface functions will however (from version 0.2-2) only work outside GRASS, to avoid possible overwriting of GRASS database locations and/or files.}

\seealso{\code{\link[spatial]{trmat}}}

\examples{
data(utm.maas)
G <- maas.metadata
if(G$Ncells != length(maasmask))
    stop("example not running in Maas GRASS location")
require(spatial)
s1 <- surf.ls(1, utm.maas$east, utm.maas$north, utm.maas$Zn)
s2 <- surf.ls(2, utm.maas$east, utm.maas$north, utm.maas$Zn)
s3 <- surf.ls(3, utm.maas$east, utm.maas$north, utm.maas$Zn)
s4 <- surf.ls(4, utm.maas$east, utm.maas$north, utm.maas$Zn)
summary(s2)
summary(s3)
summary(s4)
anova(s2,s3,s4)
plot(G, trmat.G(G, s3)*maasmask, breaks=c(-10000, seq(-100, 1500, 200),
  10000), col=c("yellow", grey(8:1/8), "red"))
plot(G, ifelse(is.na(maasmask), 1, NA), col="wheat", add=TRUE)
plot(s3, add=TRUE)
legend(c(269900, 270600), c(5652000, 5652900), bty="n", bg="wheat",
  legend=c("> 1500", rev(legtext(seq(-100,1500,200))), "< -100", "mask=NA"),
  fill=c("red", rev(grey(8:1/8)), "yellow", "wheat"))
oldpar <- par(mfrow=c(2,2))
plot(G, trmat.G(G, s1)*maasmask, breaks=c(-10000, seq(-100, 1500, 200),
  10000), col=c("yellow", grey(8:1/8), "red"))
plot(G, ifelse(is.na(maasmask), 1, NA), col="wheat", add=TRUE)
plot(s1, add=TRUE)
plot(G, trmat.G(G, s2)*maasmask, breaks=c(-10000, seq(-100, 1500, 200),
  10000), col=c("yellow", grey(8:1/8), "red"))
plot(G, ifelse(is.na(maasmask), 1, NA), col="wheat", add=TRUE)
plot(s2, add=TRUE)
plot(G, trmat.G(G, s3)*maasmask, breaks=c(-10000, seq(-100, 1500, 200),
  10000), col=c("yellow", grey(8:1/8), "red"))
plot(G, ifelse(is.na(maasmask), 1, NA), col="wheat", add=TRUE)
plot(s3, add=TRUE)
plot(G, trmat.G(G, s4)*maasmask, breaks=c(-10000, seq(-100, 1500, 200),
  10000), col=c("yellow", grey(8:1/8), "red"))
plot(G, ifelse(is.na(maasmask), 1, NA), col="wheat", add=TRUE)
plot(s4, add=TRUE)
par(oldpar)
}
\keyword{spatial}
\keyword{IO}
\eof
% Copyright 1999-2002 by Roger S. Bivand and Markus Neteler
%
%
\name{utm.maas}
\alias{utm.maas}
\alias{maasmask}
\alias{maas.metadata}
\docType{data}
\title{Soil pollution data set}
\usage{data(utm.maas)}
\description{
The \code{utm.maas} data frame has 98 rows and 13 columns.
It records contamination of the environment by selected metals along the Dutch bank of the River Maas just north of Maastricht and contains the following columns (topsoil data were
collected as bulked samples in 1990 within a radius of 5m according to 
Burrough and McDonnell 1998: 102, 309):
}
\format{
  This data frame contains the following columns:
  \describe{
    \item{east}{a numeric vector - UTM zone 32 eastings coordinates m}
    \item{north}{a numeric vector - UTM zone 32 northings coordinates m}
    \item{x}{a numeric vector - local coordinates m}
    \item{y}{a numeric vector - local coordinates m}
    \item{elev}{a numeric vector - elevation above local reference level in meters}
    \item{d.river}{a numeric vector - distance from main River Maas channel in meters}
    \item{Cd}{a numeric vector - Cadmium in ppm}
    \item{Cu}{a numeric vector - Copper in ppm}
    \item{Pb}{a numeric vector - Lead in ppm}
    \item{Zn}{a numeric vector - Zinc in ppm}
    \item{LOI}{a numeric vector - percentage organic matter loss on ignition}
    \item{Fldf}{a numeric vector - flood frequency class, 1: annual, 2: 2-5 years, 3: every 5 years}
    \item{Soil}{a numeric vector - 3 unnamed soil types}
  }
}
\details{
Maas river bank soil pollution data

The Maas river bank soil pollution data (Limburg, The Netherlands) are
sampled along the Dutch bank of the river Maas (Meuse) north of Maastricht.
This is a flood plain of the river Maas, not far from where the Maas enters
the Netherlands (Borgharen, Itteren, about 3 to 5 km north of Maastricht).

The river Maas is at the north-west border of the project area, traversing
the area in north-east direction. Burrough et al. 1998 use a subset of the
same data set in their book (reduced area). The data have been re-projected
for the GRASS/R interface from the Dutch standard coordinate system (TDN
coordinates in stereographic projection) to UTM coordinate system zone 32,
on WGS84 ellipsoid. A GRASS LOCATION has to be defined with following
parameters: projection UTM, ellipsoid WGS84, zone 32, north 5652930, south
5650610, west 269870, east 272460, nsres 10, ewres 10, rows 232, cols 259.
The pre-defined location including the data stored column-wise in sites
lists can be downloaded from the GRASS web site, and is also contained in
the "grassmeta" object \code{maas.metadata}.

Maas  river bank dat GRASS LOCATION,
\url{http://grass.itc.it/statsgrass/maas_grass_location.tar.gz}


}
\source{
 Burrough, P. & McDonnell, R. (1998) \emph{Principles of geographical information systems}, New York: Oxford, pp. 309--311; Rikken, M.G.J., Van Rijn, R.P.G., 1993. Soil pollution with heavy metals ---
An Inquiry into Spatial Variation, Cost of Mapping and the Risk evaluation
of Copper, Cadmium, Lead and Zinc in the Floodplains of the Meuse West of
Stein, The Netherlands.  Doctoraalveldwerkverslag, Dept. of Physical
Geography, Utrecht University.
}

\note{The functions in this package are intended to work with the GRASS geographical information system. The examples for wrapper functions will will work whether or not R is running in GRASS, and whether or not the current location is that of the data set used for the examples. Examples of interface functions will however (from version 0.2-2) only work outside GRASS, to avoid possible overwriting of GRASS database locations and/or files.}

\examples{
data(utm.maas)
Zn.o <- as.ordered(cut(utm.maas$Zn, labels=c("insignificant", "low",
"medium", "high", "crisis"), breaks=c(100, 200, 400, 700, 1000, 2000), 
include.lowest=TRUE))
table(Zn.o)
plot(utm.maas$east, utm.maas$north, pch=unclass(Zn.o), xlab="", ylab="", asp=1)
legend(x=c(269900, 270500), y=c(5652000, 5652700), pch=c(1:5), 
legend=levels(Zn.o))
cat("Burrough & McDonnell p. 107\n")
round(tapply(utm.maas$Zn, as.factor(utm.maas$Fldf), mean), 2)
round(tapply(utm.maas$Zn, as.factor(utm.maas$Fldf), sd), 2)
round(tapply(log(utm.maas$Zn), as.factor(utm.maas$Fldf), mean), 3)
round(tapply(log(utm.maas$Zn), as.factor(utm.maas$Fldf), sd), 3)
round(exp(round(tapply(log(utm.maas$Zn), as.factor(utm.maas$Fldf), mean), 3)), 2)
hist(utm.maas$Zn, breaks=seq(0,2000,100), col="grey")
hist(log(utm.maas$Zn), breaks=seq(3.5,8.5,0.25), col="grey")
library(ctest)
t.test(utm.maas$Zn[utm.maas$Fldf == 2], utm.maas$Zn[utm.maas$Fldf == 3])
cat("NB: B&McD p. 108, their relative variance is (1-(RSquared))\n")
anova(lm(Zn ~ as.factor(Fldf), data=utm.maas))
summary(lm(Zn ~ as.factor(Fldf), data=utm.maas))
anova(lm(log(Zn) ~ as.factor(Fldf), data=utm.maas))
summary(lm(log(Zn) ~ as.factor(Fldf), data=utm.maas))
}
\keyword{datasets}
\eof
